@@ -1,3 +1,4 @@
+from __future__ import unicode_literals
 import arrow
 from django.db.models import DateTimeField, SubfieldBase
 from .form_fields import ArrowField as ArrowFormField
@@ -6,9 +7,6 @@ from .form_fields import ArrowField as ArrowFormField
 class ArrowField(DateTimeField):
     __metaclass__ = SubfieldBase
 
-    def get_internal_type(self):
-        return "ArrowField"
-
     def to_python(self, value):
         if isinstance(value, arrow.Arrow):
             return value
